/*
***********************************************************************************************************************
*                                     TIMER 0 example (TMR0) for LPC2103
*
* Programmer 	: 	John Leung, TechToys. Hong Kong
* Web presence  : 	www.TechToys.com.hk
* Language		: 	Keil C uVision 3.53 Demo Version
* Hardware		: 	LPC2103 demo board LPC2103 Eval 1A
* Date			: 	7th March 2008
* File			: 	tmr0_main.c
* Note			: 	This example blinks the LED wired to P0_8 at a rate of 100msec with timing provided by TIMER 0 for
*					interrupt on match MR0. A peripheral clock speed of 15MHz assumed. This speed
*					has been adjusted for a crystal freq of 12MHz with Fcck=12MHz*5, and Pclk=12MHz*5/4, i.e. 15MHz
***********************************************************************************************************************
*/  

#include <LPC2103.H>
#include "..\SYSTEM\system.h"
#include "..\IOCONFIG\ioconfig.h"

#define LED				P0_8		 		//LED connected to P0.8

#define	ON				0
#define OFF				1
#define LED_STATE		IOPIN_bit.LED
#define LED_OFF			IOSET_bit.LED = 1
#define LED_ON			IOCLR_bit.LED = 1

void DelayMs(unsigned long t);

/*
***********************************************************************************************************************
* PCKDIV set 4 in system.h, and Fcclk = 1200000*5 in which 1200000 is the external crystal, and 5 is the PLL
* multiplier defined in system.h. As a result, peripheral clock = 60MHz/4 = 15MHz
***********************************************************************************************************************
*/
void DelayMs(unsigned long t)
{
	T0PR = 149;				//Prescale 150 to obtain a tmr0 rate of 100kHz (T=0.01ms)
	T0MCR_bit.MR0INT = 1;	//enable interrupt on MR0
	T0MCR_bit.MR0RES = 1;	//reset on MR0
	T0MR0 = 100*t;			//set match register a value of 100 for exactly 1ms time base, then a factor of 't' applied
	T0TCR = 2;				//reset tmr0, when CR bit 1.
	T0TCR = 1;				//start tmr0, and most importantly to release the CR bit in this instruction
							//because the timer remains in reset until the CR bit returns 0
	while(T0IR_bit.MR0INT==0);
	T0IR_bit.MR0INT = 1;	//clear interrupt flag
}


/* main */
int main(void)
{

	sysInit();									//Set CCLK and PCLK to 60MHz 
	LED_OFF;									//set LED off to start with
	IODIR_bit.LED = 1;							//Set LED pin as output

	for(;;)
	{
			
		DelayMs(100);
		(LED_STATE==OFF)? (LED_ON):(LED_OFF);	//LED toggled here after a delay of DelayMs(xxx)

	}
}
